# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['tailwind',
 'tailwind.app_template',
 'tailwind.management',
 'tailwind.management.commands']

package_data = \
{'': ['*'], 'tailwind.app_template': ['static_src/css/*', 'templates/*']}

install_requires = \
['django>=2.2']

setup_kwargs = {
    'name': 'django-tailwind-postcss',
    'version': '0.11.0',
    'description': 'Tailwind CSS Framework for Django projects',
    'long_description': '# Django + Tailwind = ❤\n\n![](https://img.shields.io/pypi/l/django-tailwind-postcss)\n![](https://img.shields.io/github/workflow/status/oliverandrich/django-tailwind-postcss/Python%20package)\n![](https://img.shields.io/pypi/djversions/django-tailwind-postcss)\n![](https://img.shields.io/pypi/pyversions/django-tailwind-postcss)\n\nThis is a fork of the great project [django-tailwind](https://github.com/timonweb/django-tailwind) by [timonweb](https://github.com/timonweb). Instead of using [Sass](https://sass-lang.com) in the css procesing pipeline, I prefer to stick to a postcss only pipeline and also integrated the officials plugins, that are recommended by [Tailwind UI](https://tailwindui.com): [@tailwindcss/aspect-ratio](https://www.npmjs.com/package/@tailwindcss/aspect-ratio), [@tailwindcss/forms](https://www.npmjs.com/package/@tailwindcss/forms) and [@tailwindcss/typography](https://www.npmjs.com/package/@tailwindcss/typography). I also took the decision to strip the support for Tailwind CSS 1.x. In order to support nested rules in the css definitions, [postcss-nested](https://github.com/postcss/postcss-nested) is also added.\n\n## Installation\n\n1. Install the `django-tailwind` package via Pip:\n\n   `python -m pip install django-tailwind`\n\n2. Add `tailwind` to INSTALLED_APPS in **settings.py**\n\n3. Create a tailwind-compatible Django-app, I like to call it `theme`:\n\n   `python manage.py tailwind init theme`\n\n4. Add your newly created `theme` app to INSTALLED_APPS in **settings.py**\n\n5. In settings.py, register tailwind app by adding the following string:\n\n   `TAILWIND_APP_NAME = \'theme\'`\n\n6. Run a command to install all necessary dependencies for tailwind css:\n\n   `python manage.py tailwind install`\n\n7. Now, go and start tailwind in dev mode:\n\n   `python manage.py tailwind start`\n\n8. Django Tailwind comes with a simple `base.html` template that can be found under\n   `theme/templates/base.html`. Feel free to extend it as needed. If you don\'t want\n   to use the default template, you have add the link for styles.css manually to\n   your base template.\n\n   ```html\n   <link\n     rel="stylesheet"\n     href="{% static \'css/styles.css\' %}"\n     type="text/css"\n   />\n   ```\n\n## Production Builds\n\nTo build a production version of CSS run:\n\n```\npython manage.py tailwind build\n```\n\n## Adding your custom base styles, components and utilities\n\nIn order to define your on base styles, components and utilties as described in the documents [Adding Base Styles](https://tailwindcss.com/docs/adding-base-styles), [Extracting Components](https://tailwindcss.com/docs/extracting-components#extracting-component-classes-with-apply) and [Adding New Utilities](https://tailwindcss.com/docs/adding-new-utilities), just add them the corresponding layers defined in `theme/static_src/src/styles.css`.\n\n## PurgeCSS setup\n\nTo avoid importing all of Tailwind (resulting in a massive CSS filesize),\nset up the purge configuration in `tailwind.config.js`. This file is located\nin the `static_src` folder of the app created by `tailwind init {APP_NAME}`.\n\n```js\nmodule.exports = {\n  purge: [\n    // Templates within theme app (e.g. base.html)\n    \'../templates/**/*.html\',\n    // Templates in other apps\n    \'../../templates/**/*.html\',\n  ],\n  ...\n}\n```\n\nNote that you may need to adjust those paths to suit your specific project layout. It is important to ensure that _all_ of your HTML files are covered (or files with contain HTML content, such as .vue or .jsx files), to enusre PurgeCSS can whitelist all of your classes.\n\nFor more information on this, check out the "Controlling File Size" page of the Tailwind docs: [https://tailwindcss.com/docs/controlling-file-size/#removing-unused-css](https://tailwindcss.com/docs/controlling-file-size/#removing-unused-css) - particularly the "Removing Unused CSS" section, although the entire page is a useful reference.\n\nTo help speed up development builds, PurgeCSS is only run when you use the `tailwind build` management command (to create a production build of your CSS).\n\n## NPM executable path configuration\n\nSometimes (especially on Windows), Python executable can\'t find `NPM` installed in the system.\nIn this case, you need to set `NPM` executable path in settings.py file manually (Linux/Mac):\n\n```python\nNPM_BIN_PATH = \'/usr/local/bin/npm\'\n```\n\nOn windows it might look like:\n\n```python\nNPM_BIN_PATH = r"C:\\Program Files\\nodejs\\npm.cmd"\n```\n\nPlease note that `NPM` path of your system may be different. Try to run `which npm` in your\ncommand line to get the path.\n\n## Updating Tailwind CSS and dependencies\n\nIf there\'s a new release of the tailwind css came out you can always update your `theme` project\nwithout updating this django package by using two commands: `python manage.py tailwind check-updates` and `python manage.py tailwind update`.\n\n## Bugs and suggestions\n\nIf you have found a bug, please use the issue tracker on GitHub.\n\n[https://github.com/oliverandrich/django-tailwind-postcss/issues](https://github.com/timonweb/django-tailwind/issues)\n',
    'author': 'Oliver Andrich',
    'author_email': 'oliver@andrich.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/oliverandrich/django-tailwind-postcss',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
